@@ -9,7 +9,7 @@ from flexget import logger, plugin
 from flexget.manager import Manager
 from flexget.options import get_parser
 
-__version__ = '1.2.191'
+__version__ = '1.2.192'
 
 log = logging.getLogger('main')
 
@@ -25,12 +25,6 @@ def main(args=None):
 
     manager = Manager(options)
 
-    log_level = logging.getLevelName(options.loglevel.upper())
-    log_file = os.path.expanduser(manager.options.logfile)
-    # If an absolute path is not specified, use the config directory.
-    if not os.path.isabs(log_file):
-        log_file = os.path.join(manager.config_base, log_file)
-    logger.start(log_file, log_level)
     if options.profile:
         try:
             import cProfile as profile
